@@ -1,4 +1,5 @@
 import os
+from datetime import timedelta
 from pathlib import Path
 from configurations import Configuration, values
 
@@ -31,6 +32,8 @@ class BaseConfig(Configuration):
         'import_export',
         'django_extensions',
         'rest_framework',
+        'rest_framework_simplejwt',
+        'rest_framework_simplejwt.token_blacklist',
         'storages',
         'corsheaders',
         'djangoql',
@@ -258,3 +261,22 @@ class BaseConfig(Configuration):
 
     # ckeditor
     CKEDITOR_UPLOAD_PATH = 'ckeditor_uploads/'
+
+    REST_FRAMEWORK = {
+        'DEFAULT_AUTHENTICATION_CLASSES': (
+            'rest_framework_simplejwt.authentication.JWTAuthentication',
+        )
+    }
+    SIMPLE_JWT_SIGNING_KEY = values.Value()
+
+    @property
+    def SIMPLE_JWT(self):
+        return {
+            'ACCESS_TOKEN_LIFETIME': timedelta(hours=1),
+            'REFRESH_TOKEN_LIFETIME': timedelta(hours=24),
+            'SIGNING_KEY': self.SIMPLE_JWT_SIGNING_KEY or self.SECRET_KEY,
+            'ROTATE_REFRESH_TOKENS': True,
+            'BLACKLIST_AFTER_ROTATION': True
+        }
+
+    CORS_ALLOWED_ORIGINS = values.ListValue()
